# Database Migrations

For the purposes of this workshop, you don't need to mess at all with database migrations (woohoo!). If you are curious about these, please refer to the [beginner workshop section on this topic.](../beginner/database-migration.md)
